@@ -1,27 +1,31 @@
-#' Ape Time
+#' Read modification time from 'ape' Nexus file
 #'
-#' Reads the time that an ape tree was modified from the comment in the Nexus
-#' file.
+#' `ApeTime()` reads the time that a tree written with 'ape' was modified,
+#' based on the comment in the Nexus file.
 #'
-#' @param filename Character string specifying path to the file
+#' @param filename Character string specifying path to the file.
 #' @param format Format in which to return the time: 'double' as a sortable numeric;
-#'               any other value to return a string in the format YYYY-MM-DD hh:mm:ss
+#'               any other value to return a string in the format
+#'               `YYYY-MM-DD hh:mm:ss`.
 #'
-#' @return `ApeTime` returns the time that the specified file was created by
+#' @return `ApeTime()` returns the time that the specified file was created by
 #' ape, in the format specified by `format`.
 #' @export
 #' @template MRS
 #'
-ApeTime <- function (filename, format='double') {
-  if (length(filename) > 1L) stop("`filename` must be a character string of length 1")
-  comment <- readLines(filename, n=2)[2]
+ApeTime <- function (filename, format = 'double') {
+  if (length(filename) > 1L) {
+    stop("`filename` must be a character string of length 1")
+  }
+  comment <- readLines(filename, n = 2)[2]
   Month <- function (month) {
-    months <- c('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec')
+    months <- c('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
+                'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec')
     whichMonth <- months == month
     if (any(whichMonth)) {
-      formatC(which (whichMonth), width=2, flag="0")
+      formatC(which(whichMonth), width = 2, flag = "0")
     } else {
-      month
+      month                                                                     # nocov
     }
   }
   DATEEXP <- ".*? (\\w+)\\s(\\d+)\\s(\\d+\\:\\d\\d\\:\\d\\d)\\s(\\d\\d\\d\\d).*"
@@ -30,19 +34,19 @@ ApeTime <- function (filename, format='double') {
                  gsub(DATEEXP, "-\\2 \\3", comment))
 
   # Return:
-  ifelse(format=='double', as.numeric(as.POSIXct(time, tz = "GMT")), time)
+  ifelse(format == 'double', as.numeric(as.POSIXct(time, tz = "GMT")), time)
 }
 
 #' Parse TNT Tree
 #'
-#' Reads a tree from TNT's parenthetical output.
+#' Read a tree from TNT's parenthetical output.
 #'
 #' [TNT](http://www.lillo.org.ar/phylogeny/tnt/) is software for parsimony
 #' analysis.  Whilst its implementation of tree search is extremely rapid,
 #' analysis of results in TNT is made difficult by its esoteric and scantly
 #' documented scripting language.
 #'
-#' `ReadTNTTree` aims to aid the user by facilitating the import of trees
+#' `ReadTntTree()` aims to aid the user by facilitating the import of trees
 #' generated in TNT into R for further analysis.
 #'
 #' The function depends on tree files being saved by TNT in parenthetical
@@ -52,9 +56,9 @@ ApeTime <- function (filename, format='double') {
 #' contains tip labels and can be parsed directly.  The downside is that the
 #' uncompressed `.tre` files will have a larger file size.
 #'
-#' `ReadTNTTree` can also read `.tre` files in which taxa have been saved using
-#' their numbers (`taxname-`).  Such files contain a hard-coded link to the
-#' matrix file that was used to generate the trees, in the first line of the
+#' `ReadTntTree()` can also read `.tre` files in which taxa have been saved
+#' using their numbers (`taxname-`).  Such files contain a hard-coded link to
+#' the matrix file that was used to generate the trees, in the first line of the
 #' `.tre` file.  This poses problems for portability: if the matrix file is
 #' moved, or the `.tre` file is accessed on another computer, the taxon names
 #' may be lost.  As such, it is important to check that the matrix file
@@ -62,6 +66,9 @@ ApeTime <- function (filename, format='double') {
 #' either use the `relativePath` argument to point to its new location, or
 #' specify `tipLabels` to manually specify the tip labels.
 #'
+#' `TntText2Tree()` converts text representation of a tree in TNT to an
+#'  object of class `phylo`.
+#'
 #' @param filename character string specifying path to TNT `.tre` file,
 #' relative to the R working directory (visible with `getwd()`).
 #' @param relativePath (discouraged) character string specifying location of the
@@ -75,53 +82,55 @@ ApeTime <- function (filename, format='double') {
 #' taxon names will be loaded from the data file linked in the first line of the
 #'  `.tre` file specified in `filename`.
 #'
-#' @return `ReadTNTTree` returns a tree of class \code{phylo}, corresponding
+#' @return `ReadTntTree()` returns a tree of class \code{phylo}, corresponding
 #' to the tree in `filename`.
 #'
 #' @examples
-#'   # In the examples below, TNT has read a matrix from
-#'   # "c:/TreeTools/input/dataset.nex"
-#'   # The results of an analysis were written to
-#'   # "c:/TreeTools/output/results1.tnt"
-#'   #
-#'   # results1.tnt will contain a hard-coded reference to
-#'   # "c:/TreeTools/input/dataset.nex".
+#' # In the examples below, TNT has read a matrix from
+#' # "c:/TreeTools/input/dataset.nex"
+#' # The results of an analysis were written to
+#' # "c:/TreeTools/output/results1.tnt"
+#' #
+#' # results1.tnt will contain a hard-coded reference to
+#' # "c:/TreeTools/input/dataset.nex".
 #'
-#'   # On the original machine (but not elsewhere), it would be possible to read
-#'   # this hard-coded reference from results.tnt:
-#'   # ReadTntTree('output/results1.tnt')
+#' # On the original machine (but not elsewhere), it would be possible to read
+#' # this hard-coded reference from results.tnt:
+#' # ReadTntTree('output/results1.tnt')
 #'
-#'   # These datasets are provided with the `TreeTools` package, which will
-#'   # probably not be located at c:/TreeTools on your machine:
+#' # These datasets are provided with the 'TreeTools' package, which will
+#' # probably not be located at c:/TreeTools on your machine:
 #'
-#'   oldWD <- getwd() # Remember the current working directory
-#'   setwd(system.file(package = 'TreeTools'))
+#' oldWD <- getwd() # Remember the current working directory
+#' setwd(system.file(package = 'TreeTools'))
 #'
-#'   # If taxon names were saved within the file (using `taxname=` in TNT),
-#'   # then our job is easy:
-#'   ReadTntTree('extdata/output/named.tre')
+#' # If taxon names were saved within the file (using `taxname=` in TNT),
+#' # then our job is easy:
+#' ReadTntTree('extdata/output/named.tre')
 #'
-#'   # But if taxa were compressed to numbers (using `taxname-`), we need to
-#'   # look up the original matrix in order to dereference the tip names.
-#'   #
-#'   # We need to extract the relevant file path from the end of the
-#'   # hard-coded path in the original file.
-#'   #
-#'   # We are interested in the last two elements of
-#'   # c:/TreeTools/input/dataset.nex
-#'   #                2      1
-#'   #
-#'   # '.' means "relative to the current directory"
-#'   ReadTntTree('extdata/output/numbered.tre', './extdata', 2)
+#' # But if taxa were compressed to numbers (using `taxname-`), we need to
+#' # look up the original matrix in order to dereference the tip names.
+#' #
+#' # We need to extract the relevant file path from the end of the
+#' # hard-coded path in the original file.
+#' #
+#' # We are interested in the last two elements of
+#' # c:/TreeTools/input/dataset.nex
+#' #                2      1
+#' #
+#' # '.' means "relative to the current directory"
+#' ReadTntTree('extdata/output/numbered.tre', './extdata', 2)
 #'
-#'   # If working in a lower subdirectory
-#'   setwd('./extdata/otherfolder')
+#' # If working in a lower subdirectory
+#' setwd('./extdata/otherfolder')
 #'
-#'   # then it will be necessary to navigate up the directory path with '..':
-#'   ReadTntTree('../output/numbered.tre', '..', 2)
+#' # then it will be necessary to navigate up the directory path with '..':
+#' ReadTntTree('../output/numbered.tre', '..', 2)
 #'
 #'
-#'   setwd(oldWD) # Restore original working directory
+#' setwd(oldWD) # Restore original working directory
+#'
+#' TNTText2Tree("(A (B (C (D E ))));")
 #'
 #' @template MRS
 #' @importFrom ape read.tree
@@ -141,8 +150,8 @@ ReadTntTree <- function (filename, relativePath = NULL, keepEnd = 1L,
         taxonFileParts <- strsplit(taxonFile, '/')[[1]]
         nParts <- length(taxonFileParts)
         if (nParts < keepEnd) {
-          stop("Taxon file path (", taxonFile, ") contains fewer than keepEnd (",
-               keepEnd, ") components.")
+          stop("Taxon file path (", taxonFile,                                  # nocov
+               ") contains fewer than keepEnd (", keepEnd, ") components.")     # nocov
         }
         taxonFile <- paste0(c(relativePath,
                               taxonFileParts[(nParts + 1L - keepEnd):nParts]),
@@ -150,7 +159,7 @@ ReadTntTree <- function (filename, relativePath = NULL, keepEnd = 1L,
       }
 
       if (!file.exists(taxonFile)) {
-        warning("Cannot find linked data file:\n  ", taxonFile)
+        warning("Cannot find linked data file:\n  ", taxonFile)                 # nocov
       } else {
         tipLabels <- rownames(ReadTntCharacters(taxonFile, 1))
         if (is.null(tipLabels)) {
@@ -158,11 +167,10 @@ ReadTntTree <- function (filename, relativePath = NULL, keepEnd = 1L,
           tipLabels <- rownames(ReadCharacters(taxonFile, 1))
         }
         if (is.null(tipLabels)) {
-          warning("Could not read taxon names from linked TNT file:\n  ",
-                  taxonFile,
-                  "\nIs the file in TNT or Nexus format?",
-                  " If failing inexplicably, please report:",
-                  "\n  https://github.com/ms609/TreeTools/issues/new")
+          warning("Could not read taxon names from linked TNT file:\n  ",       # nocov
+                  taxonFile, "\nIs the file in TNT or Nexus format?",           # nocov
+                  " If failing inexplicably, please report:",                   # nocov
+                  "\n  https://github.com/ms609/TreeTools/issues/new")          # nocov
         }
       }
     }
@@ -177,7 +185,7 @@ ReadTntTree <- function (filename, relativePath = NULL, keepEnd = 1L,
   if (length(trees) == 1) {
     trees[[1]]
   } else if (length(trees) == 0) {
-    NULL
+    NULL                                                                        # nocov
   } else {
     class(trees) <- 'multiPhylo'
     trees
@@ -185,13 +193,11 @@ ReadTntTree <- function (filename, relativePath = NULL, keepEnd = 1L,
 
 }
 
-#' @describeIn ReadTntTree Converts text representation of a tree in TNT to an
-#'  object of class `phylo`.
+#' @rdname ReadTntTree
 #' @param treeText Character string describing a tree, in the parenthetical
 #'                 format output by TNT.
-#' @template MRS
 #' @export
-TNTText2Tree <- function (treeText) {
+TntText2Tree <- function (treeText) {
   treeText <- gsub("([\\w']+)", "\\1,", treeText, perl = TRUE)
   treeText <- gsub(")(", "),(", treeText, fixed = TRUE)
   treeText <- gsub("*", ";", treeText, fixed = TRUE)
@@ -199,18 +205,22 @@ TNTText2Tree <- function (treeText) {
   read.tree(text=gsub(", )", ")", treeText, fixed=TRUE))
 }
 
+#' @rdname ReadTntTree
+#' @export
+TNTText2Tree <- TntText2Tree
+
 #' Extract taxa from a matrix block
 #'
-#' Reads the character information from a Nexus-formatted matrix into R.
+#' Extract leaf labels and character states from a Nexus-formatted matrix.
 #'
-#' Extracts the names of tips from the matrix block of a Nexus file.
-#'
-#' @param matrixLines lines of a file containing a phylogenetic matrix
-#'  (see [`ReadCharacters`] for expected format).
+#' @param matrixLines Character vector containing lines of a file that include
+#' a phylogenetic matrix. See [`ReadCharacters()`] for expected format.
 #' @template characterNumParam
 #' @template sessionParam
+#' @param continuous Logical specifying whether characters are continuous.
+#' Treated as discrete if `FALSE`.
 #'
-#' @return `ExtractTaxa` returns a matrix with _n_ rows, each named for the
+#' @return `ExtractTaxa()` returns a matrix with _n_ rows, each named for the
 #' relevant taxon, and _c_ columns,
 #' each corresponding to the respective character specified in `character_num`.
 #'
@@ -222,10 +232,11 @@ TNTText2Tree <- function (treeText) {
 #'
 #' @keywords internal
 #' @export
-ExtractTaxa <- function (matrixLines, character_num=NULL, session=NULL) {
+ExtractTaxa <- function (matrixLines, character_num = NULL, session = NULL,
+                         continuous = FALSE) {
   taxonLine.pattern <- "('([^']+)'|\"([^\"+])\"|(\\S+))\\s+(.+)$"
 
-  taxonLines <- regexpr(taxonLine.pattern, matrixLines, perl=TRUE) > -1
+  taxonLines <- regexpr(taxonLine.pattern, matrixLines, perl = TRUE) > -1
   # If a line does not start with a taxon name, join it to the preceding line
   taxonLineNumber <- which(taxonLines)
   previousTaxon <- vapply(which(!taxonLines), function (x) {
@@ -233,17 +244,29 @@ ExtractTaxa <- function (matrixLines, character_num=NULL, session=NULL) {
   }, integer(1))
 
 
-  taxa <- sub(taxonLine.pattern, "\\2\\3\\4", matrixLines, perl=TRUE)
+  taxa <- sub(taxonLine.pattern, "\\2\\3\\4", matrixLines, perl = TRUE)
   taxa <- gsub(" ", "_", taxa, fixed=TRUE)
   taxa[!taxonLines] <- taxa[previousTaxon]
   uniqueTaxa <- unique(taxa)
 
-  tokens <- sub(taxonLine.pattern, "\\5", matrixLines, perl=TRUE)
-  tokens <- gsub("\t", "", gsub(" ", "", tokens, fixed=TRUE), fixed=TRUE)
-  tokens <- vapply(uniqueTaxa,
-                   function (taxon) paste0(tokens[taxa==taxon], collapse=''),
-                   character(1))
-  tokens <- NexusTokens(tokens, character_num=character_num, session=session)
+  tokens <- sub(taxonLine.pattern, "\\5", matrixLines, perl = TRUE)
+  if (continuous) {
+    tokens <- strsplit(tokens, "\\s+")
+    lengths <- vapply(tokens, length, 0L)
+    if (length(unique(lengths)) != 1) {
+      stop("Different numbers of tokens in different taxa: ",                   # nocov
+           paste(lengths, collapse = ', '))                                     # nocov
+    }
+    tokens <- t(vapply(tokens, I, tokens[[1]]))
+  } else {
+    tokens <- gsub("\t", "", gsub(" ", "", tokens, fixed = TRUE), fixed = TRUE)
+    tokens <- vapply(uniqueTaxa,
+                     function (taxon) paste0(tokens[taxa == taxon],
+                                             collapse = ''),
+                     character(1))
+    tokens <- NexusTokens(tokens, character_num = character_num,
+                          session = session)
+  }
 
   rownames(tokens) <- uniqueTaxa
 
@@ -251,31 +274,31 @@ ExtractTaxa <- function (matrixLines, character_num=NULL, session=NULL) {
   tokens
 }
 
+#' @rdname ExtractTaxa
 #' @param tokens Vector of character strings corresponding to phylogenetic
 #'  tokens.
-#' @describeIn ExtractTaxa Converts a Nexus string to a vector of character
-#'  states.
-#' @return `NexusTokens` returns a character vector in which each entry
-#' corresponds to the states of a phylogenetic character.
+#' @return `NexusTokens()` returns a character vector in which each entry
+#' corresponds to the states of a phylogenetic character, or a list containing
+#' an error message if input is invalid.
 #' @examples
 #' NexusTokens('01[01]-?')
 #' @export
-NexusTokens <- function (tokens, character_num=NULL, session=NULL) {
+NexusTokens <- function (tokens, character_num = NULL, session = NULL) {
   tokens.pattern <- "\\([^\\)]+\\)|\\[[^\\]]+\\]|\\{[^\\}]+\\}|\\S"
   matches <- gregexpr(tokens.pattern, tokens, perl=TRUE)
 
   nChar <- length(matches[[1]])
 
   if (!is.null(session) && requireNamespace('shiny', quietly = TRUE)) {
-    shiny::updateNumericInput(session, 'character_num', max = nChar)
+    shiny::updateNumericInput(session, 'character_num', max = nChar)            # nocov
   }
 
   if (!exists("character_num") || is.null(character_num)) {
     character_num <- seq_len(nChar)
   } else if (any(character_num > nChar) || any(character_num < 1)) {
-    return(list("Character number must be between 1 and ", nChar, "."))
-    character_num[character_num < 1] <- 1
+    character_num[character_num < 1] <- 1L
     character_num[character_num > nChar] <- nChar
+    return(list(paste0("Character number must be between 1 and ", nChar, ".")))
   }
 
   tokens <- t(vapply(regmatches(tokens, matches),
@@ -291,24 +314,32 @@ NexusTokens <- function (tokens, character_num=NULL, session=NULL) {
   tokens
 }
 
-#' Read characters from Nexus file
+#' Read phylogenetic characters from file
 #'
-#' Parses a Nexus file, reading character states and names.
+#' Parse a Nexus or TNT file, reading character states and names.
 #'
-#' Tested with nexus files downloaded from MorphoBank with the "no notes"
-#' option, but should also work more generally.
-#'
-#' Please [report](https://github.com/ms609/TreeTools/issues/new?title=Error+parsing+Nexus+file&body=<!--Tell+me+more+and+attach+your+file...-->)
+#' Tested with matrices downloaded from [MorphoBank](https://morphobank.org),
+#' but should also work more widely; please
+#' [report](https://github.com/ms609/TreeTools/issues/new?title=Error+parsing+Nexus+file&body=<!--Tell+me+more+and+attach+your+file...-->)
 #' incorrectly parsed files.
 #'
+#' Matrices must contain only continuous or only discrete characters;
+#' maximum one matrix per file.  Continuous characters will be read as strings
+#' (i.e. base type 'character').
+#'
 #' @param filepath character string specifying location of file
 #' @template characterNumParam
 #' @template sessionParam
 #'
-#' @return A matrix whose row names correspond to tip labels, and column names
-#'         correspond to character labels, with the attribute `state.labels`
-#'         listing the state labels for each character; or a character string
-#'         explaining why the character cannot be returned.
+#' @return `ReadCharacters()` and `ReadTNTCharacters()` return a matrix whose
+#' row names correspond to
+#' tip labels, and column names correspond to character labels, with the
+#' attribute `state.labels` listing the state labels for each character; or
+#' a list of length one containing a character string explaining why the
+#' function call was unsuccessful.
+#'
+#' `ReadAsPhyDat()` and `ReadTntAsPhyDat()` return a
+#' [`phyDat`][phangorn::phyDat] object.
 #'
 #' @template MRS
 #' @references
@@ -319,11 +350,22 @@ NexusTokens <- function (tokens, character_num=NULL, session=NULL) {
 #'                    '/extdata/input/dataset.nex')
 #' ReadCharacters(fileName)
 #'
+#' fileName <- paste0(system.file(package='TreeTools'),
+#'                    '/extdata/tests/continuous.nex')
+#' continuous <- ReadCharacters(fileName)
+#'
+#' # To convert from strings to numbers:
+#' at <- attributes(continuous)
+#' continuous <- suppressWarnings(as.numeric(continuous))
+#' attributes(continuous) <- at
+#' continuous
+#'
+#' @seealso Convert between matrices and `phyDat` objects: [`MatrixToPhyDat()`]
 #' @export
-ReadCharacters <- function (filepath, character_num=NULL, session=NULL) {
+ReadCharacters <- function (filepath, character_num = NULL, session = NULL) {
 
-  lines <- readLines(filepath, warn=FALSE) # Missing EOL is quite common, so
-                                           # warning not helpful
+  lines <- readLines(filepath, warn = FALSE) # Missing EOL is quite common, so
+                                             # warning not helpful
   nexusComment.pattern <- "\\[[^\\]*\\]"
   lines <- gsub(nexusComment.pattern, "", lines)
   lines <- trimws(lines)
@@ -332,17 +374,19 @@ ReadCharacters <- function (filepath, character_num=NULL, session=NULL) {
   semicolons <- which(RightmostCharacter(lines) == ';')
   upperLines <- toupper(lines)
 
+  continuous <- length(grep('DATATYPE[\\S\\=]+CONTINUOUS', upperLines)) > 0
   matrixStart <- which(upperLines == 'MATRIX')
   if (length(matrixStart) == 0) {
     return(list("MATRIX block not found in Nexus file."))
   } else if (length (matrixStart) > 1) {
-    return(list("Multiple MATRIX blocks found in Nexus file."))
+    return(list("Multiple MATRIX blocks found in Nexus file."))                 # nocov
   } else {
     matrixEnd <- semicolons[semicolons > matrixStart][1]
     if (lines[matrixEnd] == ';') matrixEnd <- matrixEnd - 1
 
     matrixLines <- lines[(matrixStart + 1):matrixEnd]
-    tokens <- ExtractTaxa(matrixLines, character_num, session)
+    tokens <- ExtractTaxa(matrixLines, character_num = character_num,
+                          session = session, continuous = continuous)
     if (is.null(character_num)) character_num <- seq_len(ncol(tokens))
 
     ## Written with MorphoBank format in mind: each label on separate line,
@@ -384,9 +428,9 @@ ReadCharacters <- function (filepath, character_num=NULL, session=NULL) {
 }
 
 
-#' @describeIn ReadCharacters Read characters from TNT file
+#' @rdname ReadCharacters
 #' @export
-ReadTntCharacters <- function (filepath, character_num=NULL, session=NULL) {
+ReadTntCharacters <- function (filepath, character_num = NULL, session = NULL) {
 
   lines <- readLines(filepath, warn=FALSE) # Missing EOL might occur in user-
                                            # generated file, so warning not helpful
@@ -448,17 +492,19 @@ ReadTntCharacters <- function (filepath, character_num=NULL, session=NULL) {
   tokens
 }
 
-#' Matrix to `phyDat`
+#' Convert between matrices and `phyDat` objects
 #'
-#' Converts a matrix of tokens to a `phyDat` object.
+#' `MatrixToPhyDat()` converts a matrix of tokens to a `phyDat` object;
+#' `PhyDatToMatrix()` converts a `phyDat` object to a matrix of tokens.
 #'
-#' @param tokens matrix of tokens, probably created with [`ReadCharacters`]
-#'               or [`ReadTntCharacters`]. Row names should correspond to tip
+#' @param tokens matrix of tokens, probably created with [`ReadCharacters()`]
+#'               or [`ReadTntCharacters()`]. Row names should correspond to tip
 #'               labels; column names may optionally correspond to
 #'               character labels.
 #'
-#' @return an object of class `phyDat`.
+#' @return `MatrixToPhyDat()` returns an object of class `phyDat`.
 #'
+#' @family phylogenetic matrix conversion functions
 #' @template MRS
 #' @keywords internal
 #' @export
@@ -480,7 +526,7 @@ MatrixToPhyDat <- function (tokens) {
   dat
 }
 
-#' @describeIn MatrixToPhyDat Converts a `phyDat` object to a matrix of tokens.
+#' @rdname MatrixToPhyDat
 #' @param dataset A dataset of class `phyDat`.
 ## @param parentheses Character vector specifying style of parentheses
 ## with which to enclose ambiguous characters, e.g, `c('[', ']')` will render
@@ -497,7 +543,7 @@ PhyDatToMatrix <- function (dataset) {#}, parentheses = c('[', ']'), sep = '') {
   t(vapply(dataset, function (x) allLevels[x[index]], character(length(index))))
 }
 
-#' @describeIn ReadCharacters Read Nexus characters as `phyDat` object.
+#' @rdname ReadCharacters
 #' @importFrom phangorn phyDat
 #' @export
 ReadAsPhyDat <- function (filepath) {
@@ -505,7 +551,7 @@ ReadAsPhyDat <- function (filepath) {
 }
 
 
-#' @describeIn ReadCharacters Read TNT characters as `phyDat` object.
+#' @rdname ReadCharacters
 #' @importFrom phangorn phyDat
 #' @export
 ReadTntAsPhyDat <- function (filepath) {
@@ -514,14 +560,14 @@ ReadTntAsPhyDat <- function (filepath) {
 
 
 #' @describeIn ReadCharacters A convenient wrapper for \pkg{phangorn}'s
-#' `phyDat()`, which converts a *list* of morphological characters into a
+#' `phyDat()`, which converts a **list** of morphological characters into a
 #' `phyDat` object.
-#' If your morphological characters are in the form of a *matrix*, perhaps
-#' because they have been read using `read.table`, try [`MatrixToPhyDat()`]
+#' If your morphological characters are in the form of a **matrix**, perhaps
+#' because they have been read using [`read.table()`], try [`MatrixToPhyDat()`]
 #' instead.
 #'
 #' @param dataset list of taxa and characters, in the format produced by [read.nexus.data]:
-#'                a list of sequences each made of a single vector of mode character,
+#'                a list of sequences each made of a single character vector,
 #'                and named with the taxon name.
 #'
 #' @export
@@ -535,59 +581,54 @@ PhyDat <- function (dataset) {
   MatrixToPhyDat(mat)
 }
 
-#' String to `phyDat`
-#'
-#' Converts a character string to a `phyDat` object.
+#' @rdname PhyToString
 #'
 #' @param string String of tokens, optionally containing whitespace, with no
 #'   terminating semi-colon.
 #' @param tips Character vector corresponding to the names (in order)
 #' of each taxon in the matrix.
 #' @param byTaxon Logical; if `TRUE`, string is one **taxon's** coding at a
-#' time; if `FALSE`, string is interpreted as one ***character's** coding at a
+#' time; if `FALSE`, string is interpreted as one **character's** coding at a
 #' time.
 #'
+#' @return `StringToPhyDat()` returns an object of class `phyDat`.
+#'
 #' @examples
-#' morphy <- StringToPhyDat("-?01231230?-", c('Lion', 'Gazelle'), byTaxon = TRUE)
+#' StringToPhyDat("-?01231230?-", c('Lion', 'Gazelle'), byTaxon = TRUE)
 #' # encodes the following matrix:
 #' # Lion     -?0123
 #' # Gazelle  1230?-
 #'
-#' @template returnPhydat
-#' @seealso \code{\link{phyDat}}
-#'
-#' @template MRS
-#' @aliases StringToPhydat
-#' @seealso
-#' - [`PhyToString`]
 #' @importFrom phangorn phyDat
 #' @export
-StringToPhyDat <-
-  function (string, tips, byTaxon = TRUE) {
+StringToPhyDat <- function (string, tips, byTaxon = TRUE) {
     tokens <- matrix(NexusTokens(string), nrow = length(tips), byrow = byTaxon)
     rownames(tokens) <- tips
     MatrixToPhyDat(tokens)
   }
-#' @rdname StringToPhyDat
+#' @rdname PhyToString
 StringToPhydat <- StringToPhyDat
 
-#' `phyDat` to String
+#' Convert between strings and `phyDat` objects
 #'
-#' Extract character data from a `phyDat` object as a string.
+#' `PhyDatToString()` converts a [`phyDat`][phangorn::phyDat] object as a
+#' string;
+#' `StringToPhyDat()` converts a string of character data to a `phyDat` object.
 #'
-#' @param phy An object of class \code{\link{phyDat}}
-#' @param parentheses Character specifying format of parentheses with which
-#' to surround ambiguous tokens.  Choose from: `\{` (default), `[`, `(`, `<`.
+#' @param phy An object of class [`phyDat`][phangorn::phyDat].
+#' @param parentheses Character specifying format of parentheses with which to
+#' surround ambiguous tokens.  Choose from: \code{\{} (default), `[`, `(`, `<`.
 #' @param collapse Character specifying text, perhaps `,`, with which to
-#' separate multiple tokens within parentheses
-#' @param ps Character specifying text, perhaps `;`, to append to the end of the string
+#' separate multiple tokens within parentheses.
+#' @param ps Character specifying text, perhaps `;`, to append to the end of
+#' the string.
 #' @param useIndex Logical (default: `TRUE`) specifying whether to print
-#' duplicate characters multiple times, as they appeared in the original matrix
+#' duplicate characters multiple times, as they appeared in the original matrix.
 #' @param byTaxon Logical. If `TRUE`, write one taxon followed by the next.
-#'                If `FALSE`, write one character followed by the next.
-#' @param concatenate Logical specifying whether to concatenate all characters/taxa
-#'                    into a single string, or to return a separate string
-#'                    for each entry.
+#' If `FALSE`, write one character followed by the next.
+#' @param concatenate Logical specifying whether to concatenate all
+#' characters/taxa into a single string, or to return a separate string for
+#' each entry.
 #'
 #' @examples
 #' fileName <- paste0(system.file(package='TreeTools'),
@@ -595,11 +636,10 @@ StringToPhydat <- StringToPhyDat
 #' phyDat <- ReadAsPhyDat(fileName)
 #' PhyToString(phyDat, concatenate = FALSE)
 #'
-#' @return `PhyToString` returns a character vector listing a text
+#' @return `PhyToString()` returns a character vector listing a text
 #' representation of the phylogenetic character state for each taxon in turn.
 #'
-#' @seealso
-#' - [`StringToPhyDat`]
+#' @family phylogenetic matrix conversion functions
 #' @template MRS
 #' @importFrom phangorn phyDat
 #' @export
@@ -666,16 +706,38 @@ PhydatToString <- PhyToString
 
 #' Rightmost character of string
 #'
-#' @param string Character string.
-#' @param len Integer specifying number of characters in `string`.
+#' `RightmostCharacter()` is a convenience function that returns the final
+#' character of a string.
 #'
-#' @return Rightmost character of `string`.
+#' @param string Character string.
+#' @param len (Optional) Integer specifying number of characters in `string`.
+#'
+#' @return `RightmostCharacter()` returns the rightmost character of a string.
 #' @examples
 #' RightmostCharacter("Hello, World!")
 #'
 #' @template MRS
 #' @export
 #' @keywords internal
-RightmostCharacter <- function (string, len=nchar(string)) {
+RightmostCharacter <- function (string, len = nchar(string)) {
   substr(string, len, len)
 }
+
+#' Write Newick Tree
+#'
+#' `NewickTree()` encodes a tree as a Newick-format string.
+#' This differs from [`write.tree()`][ape::write.tree] in the encoding of
+#' spaces as spaces, rather than underscores.
+#'
+#' @template treeParam
+#'
+#' @return `NewickTree()` returns a character string denoting `tree` in Newick
+#' format.
+#'
+#' @examples
+#' NewickTree(BalancedTree(LETTERS[4:9]))
+#'
+#' @seealso Use tip numbers, rather than leaf labels: [`as.Newick`]
+#' @importFrom ape write.tree
+#' @export
+NewickTree <- function(tree) gsub('_', ' ', write.tree(tree), fixed = TRUE)
