@@ -7,7 +7,7 @@
 #' encountered when using \code{\link[ape:root]{ape::unroot}()} on trees in
 #' preorder.
 #'
-#' @template treeParam
+#' @template tree(s)Param
 #' @param outgroupTips Vector of type character, integer or logical, specifying
 #' the names or indices of the tips to include in the outgroup.
 #'
@@ -34,7 +34,10 @@
 #' @importFrom phangorn Ancestors Descendants
 #' @importFrom ape root
 #' @export
-RootTree <- function (tree, outgroupTips) {
+RootTree <- function (tree, outgroupTips) UseMethod('RootTree')
+
+#' @export
+RootTree.phylo <- function (tree, outgroupTips) {
   tipLabels <- tree$tip.label
   if (is.character(outgroupTips)) {
     if (!all(outgroupTips %in% tipLabels)) {
@@ -64,6 +67,19 @@ RootTree <- function (tree, outgroupTips) {
   Renumber(root(tree, outgroup, resolve.root = TRUE))
 }
 
+#' @export
+RootTree.list <- function (tree, outgroupTips) {
+  lapply(tree, RootTree, outgroupTips)
+}
+
+#' @export
+RootTree.multiPhylo <- function (tree, outgroupTips) {
+  structure(RootTree.list(tree, outgroupTips), class = 'multiPhylo')
+}
+
+#' @export
+RootTree.NULL <- function (tree, outgroupTips) NULL
+
 #' @rdname RootTree
 #' @param node integer specifying node (internal or tip) to set as the root.
 #' @param resolveRoot logical specifying whether to resolve the root node.
@@ -72,7 +88,10 @@ RootTree <- function (tree, outgroupTips) {
 #' requested `node` and ordered in [`Preorder`].
 #'
 #' @export
-RootOnNode <- function (tree, node, resolveRoot = FALSE) {
+RootOnNode <- function (tree, node, resolveRoot = FALSE) UseMethod('RootOnNode')
+
+#' @export
+RootOnNode.phylo <- function (tree, node, resolveRoot = FALSE) {
   edge <- tree$edge
   parent <- edge[, 1]
   child <- edge[, 2]
@@ -158,11 +177,27 @@ RootOnNode <- function (tree, node, resolveRoot = FALSE) {
   }
 }
 
-#' @rdname RootTree
-#' @return `UnrootTree()` returns a tree of class `phylo`, in preorder,
-#' having collapsed the first child of the root node.
 #' @export
-UnrootTree <- function (tree) {
+RootOnNode.list <- function (tree, node, resolveRoot = FALSE) {
+  lapply(tree, RootOnNode, node, resolveRoot)
+}
+
+#' @export
+RootOnNode.multiPhylo <- function (tree, node, resolveRoot = FALSE) {
+  structure(RootOnNode.list(tree, node, resolveRoot), class = 'multiPhylo')
+}
+
+#' @export
+RootOnNode.NULL <- function (tree, node, resolveRoot = FALSE) NULL
+
+#' @rdname RootTree
+#' @return `UnrootTree()` returns `tree`, in preorder,
+#' having collapsed the first child of the root node in each tree.
+#' @export
+UnrootTree <- function (tree) UseMethod('UnrootTree')
+
+#' @export
+UnrootTree.phylo <- function(tree) {
   tree <- Preorder(tree)
   edge <- tree$edge
   if (dim(edge)[1] < 3) return (tree)
@@ -182,6 +217,17 @@ UnrootTree <- function (tree) {
   tree
 }
 
+#' @export
+UnrootTree.list <- function (tree) lapply(tree, UnrootTree)
+
+#' @export
+UnrootTree.multiPhylo <- function (tree) {
+  structure(UnrootTree.list(tree), class = 'multiPhylo')
+}
+
+#' @export
+UnrootTree.NULL <- function (tree) NULL
+
 #' Collapse nodes on a phylogenetic tree
 #'
 #' Collapses specified nodes or edges on a phylogenetic tree, resulting in
@@ -392,6 +438,86 @@ DropTip <- function (tree, tip) {
   }
 }
 
+#' Generate binary tree by collapsing polytomies
+#'
+#' `MakeTreeBinary()` resolves, at random, all polytomies in a tree or set of
+#' trees, such that all trees compatible with the input topology are drawn
+#' with equal probability.
+#'
+#'
+#' @seealso Resolve polytomies such that some resolutions are more probable
+#' than others using [`ape::multi2di()`].
+#'
+#' @return `MakeTreeBinary()` returns a rooted binary tree of class `phylo`,
+#' corresponding to tree uniformly selected from all those compatible with
+#' the input tree topologies.
+#'
+#' @examples
+#' MakeTreeBinary(CollapseNode(PectinateTree(7), c(9, 11, 13)))
+#' UnrootTree(MakeTreeBinary(StarTree(5)))
+#' @template MRS
+#' @template treeParam
+#' @family tree manipulation
+#' @export
+MakeTreeBinary <- function (tree) {
+  UseMethod('MakeTreeBinary')
+}
+
+#' @export
+MakeTreeBinary.phylo <- function (tree) {
+  tree <- Preorder(tree)
+  degree <- NodeOrder(tree, internalOnly = TRUE)
+  degree[1] <- degree[1] + 1L # Root node
+  polytomies <- degree > 3L
+  if (!any(polytomies)) return(tree)
+  edge <- tree$edge
+
+  nTip <- edge[1] - 1L
+  polytomyN <- which(polytomies) + nTip
+  degree <- degree[polytomies]
+  for (i in seq_len(sum(polytomies))) {
+    n <- polytomyN[i]
+    nKids <- degree[i] - 1L
+    newParent <- .RandomParent(nKids + 1L) # Tip 1 is the 'root'
+    newEdges <- RenumberEdges(newParent, seq_len(nKids + nKids))
+
+    nNewNodes <- nKids - 2L
+
+    childEdges <- edge[, 1] == n
+
+    keep <- edge[!childEdges, ]
+    increase <- keep > n
+    keep[increase] <- keep[increase] + nNewNodes
+
+    children <- edge[childEdges, 2L]
+    increase <- children > n
+    children[increase] <- children[increase] + nNewNodes
+
+    polytomyN <- polytomyN + nNewNodes
+
+    newEdges2 <- newEdges[[2]][c(-1, -2)] - 1L
+    decrease <- newEdges2 > nKids
+    newEdges2[decrease] <- newEdges2[decrease] - 2L
+
+    add <- cbind(newEdges[[1]][-(1:2)] + n - nKids - 3L,
+                 c(children, n + seq_len(nNewNodes))[newEdges2])
+
+    edge <- rbind(keep, add)
+  }
+  tree$edge <- edge
+  tree$Nnode <- nTip - 1L
+  tree
+}
+
+#' @export
+MakeTreeBinary.list <- function (tree) lapply(tree, MakeTreeBinary)
+
+#' @export
+MakeTreeBinary.multiPhylo <- function (tree) {
+  structure(MakeTreeBinary.list(tree), class = 'multiPhylo')
+}
+
+
 #' Leaf label interchange
 #'
 #' `LeafLabelInterchange()` exchanges the position of leaves within a tree.
