@@ -1,6 +1,6 @@
 context("Splits.R")
 
-test_that("as.Splits", {
+test_that("as.Splits()", {
   A <- FALSE
   B <- TRUE
   expect_equal(c("1 bipartition split dividing 4 tips, t1 .. t4",
@@ -18,9 +18,9 @@ test_that("as.Splits", {
                as.logical(as.Splits(c(A, A, B, B))))
   tree1 <- BalancedTree(letters[1:5])
   splits1 <- as.Splits(tree1)
-  expect_equal(c('7' = 'a b | c d e', '9' = 'd e | a b c'), as.character(splits1))
+  expect_equal(c('8' = 'a b | c d e', '9' = 'd e | a b c'), as.character(splits1))
   logicalSplits <- as.Splits(matrix(c(B, B, A, A, A,  A, A, A, B, B),
-                                    nrow=2, byrow = TRUE),
+                                    nrow = 2, byrow = TRUE),
                              tipLabels = letters[1:5])
   rownames(logicalSplits) <- rownames(splits1)
   expect_equal(splits1, logicalSplits)
@@ -43,20 +43,71 @@ test_that("as.Splits", {
   expect_equal("0 bipartition splits dividing 5 tips, a .. e",
                capture_output(print(as.Splits(polytomy))))
 
-  notPreorder <- structure(list(edge = structure(c(6L, 9L, 8L, 7L, 7L, 8L, 9L,
-                                            6L, 9L, 8L, 7L, 2L, 3L, 5L, 4L, 1L),
-                                          .Dim = c(8L, 2L)), Nnode = 4L,
-                         tip.label = 1:5), class = "phylo", order = "cladewise")
+  notPreorder <- structure(list(
+    edge = structure(c(6L, 9L, 8L, 7L, 7L, 8L, 9L, 6L,
+                       9L, 8L, 7L, 2L, 3L, 5L, 4L, 1L), .Dim = c(8L, 2L)),
+    Nnode = 4L, tip.label = 1:5), class = "phylo", order = "cladewise")
   expect_equal(c('7' = packBits(c(A, B, B, A, A, rep(FALSE, 3))),
                  '8' = packBits(c(A, B, B, A, B, rep(FALSE, 3)))),
                as.Splits(notPreorder)[, 1])
+})
+
+test_that('as.Splits.phylo()', {
+  rootedStar <- structure(list(edge = structure(c(7L, 8L, 8L, 8L, 8L, 8L, 7L,
+                                                  8L, 1L, 2L, 3L, 4L, 5L, 6L),
+                                                .Dim = c(7L, 2L)), Nnode = 2L,
+                               tip.label = letters[1:6]), class = "phylo")
+
+  rootedStar2 <- structure(list(edge = structure(c(8L, 8L, 8L, 8L, 8L, 7L, 7L,
+                                                   1L, 2L, 3L, 4L, 5L, 6L, 8L),
+                                                .Dim = c(7L, 2L)), Nnode = 2L,
+                               tip.label = letters[1:6]), class = "phylo")
+  nasty <- structure(list(edge = structure( # Danger: Do not plot!
+    c(9, 12, 10, 13, 11, 10, 11, 13, 10, 13, 12, 9,
+      5, 10,  1,  2,  3, 13,  9,  4, 11,  7,  8, 6),
+    .Dim = c(12, 2)), Nnode = 5L, tip.label = letters[1:8]), class = 'phylo')
+
+
+  expect_equal(c(0L, 1L), dim(as.Splits(rootedStar)))
+  expect_equal(c(0L, 1L), dim(as.Splits(rootedStar2)))
+  expected <- as.raw(as.Splits(Preorder(nasty)))
+  actual <- as.raw(as.Splits(nasty))
+  expect_equal(length(expected), length(actual))
+  expect_equal(length(actual), length(unique(actual)))
+  expect_true(all(actual %in% expected))
+  expect_true(all(expected %in% actual))
+
+  expect_equal(c(2L, 1L), dim(as.Splits(PectinateTree(5L))))
+  expect_equal(c(2L, 1L), dim(as.Splits(UnrootTree(PectinateTree(5L)))))
+
+  twoCherriesInGrass <- PectinateTree(3) + PectinateTree(3)
+  expect_equal(c(2L, 1L), dim(as.Splits(twoCherriesInGrass)))
+
+  unresolvedRoot <- CollapseNode(twoCherriesInGrass, 8)
+  expect_equal(c(1L, 1L), dim(as.Splits(unresolvedRoot)))
+  expect_equal(c(3L, 1L), dim(as.Splits(BalancedTree(6))))
+
 
   expect_equal(c(61L, 8L), dim(as.Splits(PectinateTree(64L))))
   expect_equal(c(62L, 9L), dim(as.Splits(PectinateTree(65L))))
   expect_equal(c(125L, 16L), dim(as.Splits(PectinateTree(128L))))
+
+  # Should be viable on 32-bit systems
+  expect_equal(c(7997L, 1000L), dim(as.Splits(PectinateTree(8000L))))
+
+  bigTree <- PectinateTree(16384L) # Max size with int16_t on 64-bit systems
+  bigMemory <- try(Postorder(bigTree$edge), silent = TRUE)
+  if (inherits(bigMemory, 'try-error')) {
+    expect_error(dim(as.Splits(bigTree))) # Likely on 32-bit systems
+  } else {
+    rm(bigMemory)
+    gc()
+    expect_equal(c(16381L, 2048L), dim(as.Splits(bigTree)))
+  }
+
 })
 
-test_that('as.Splits.multiPhylo', {
+test_that('as.Splits.multiPhylo()', {
   randomTreeIds <- c(30899669, 9149275, 12823175, 19740197, 31296318,
                      6949843, 30957991, 32552966, 22770711, 21678908)
   randomTrees <- as.phylo(randomTreeIds, 11L, seq_len(11L))
@@ -65,7 +116,7 @@ test_that('as.Splits.multiPhylo', {
                as.Splits(randomTrees)[[1]])
 })
 
-test_that('as.Splits.Splits', {
+test_that('as.Splits.Splits()', {
   # n tip > 8L
   splitsA <- as.Splits(ape::read.tree(text="((((a, b, c, c2), g), h), (d, (e, f)));"))
   splitsB <- as.Splits(ape::read.tree(text="(((((a, b), (c, c2)), h), g), (d, e, f));"))
@@ -73,9 +124,57 @@ test_that('as.Splits.Splits', {
                                               0, 0, 0, 0)), ncol=2), nTip = 9,
                               tip.labels = TipLabels(splitsA), class='Splits')
   actualSplits <- as.Splits(splitsB, splitsA)
-  expect_true(all(in.Splits(expectedSplits, actualSplits)))
-  expect_true(all(in.Splits(actualSplits, expectedSplits)))
+  expect_true(all(expectedSplits %in% actualSplits))
+  expect_true(all(actualSplits %in% expectedSplits))
   expect_equal(NSplits(expectedSplits), NSplits(actualSplits))
+
+  splitsABare <- splitsA
+  attr(splitsABare, 'tip.label') <- NULL
+  expect_error(as.Splits(splitsABare, 1:2))
+  expect_equal(splitsA, as.Splits(splitsABare, splitsA))
+})
+
+test_that('as.Splits.matrix()', {
+  expect_error(as.Splits(matrix(1, 3, 3)))
+  expect_error(as.Splits(matrix(1, 2, 2,
+                                dimnames = list(c('edge', 'Nnode'), NULL))))
+  trees <- list(BalancedTree(8), PectinateTree(8),
+                CollapseNode(BalancedTree(8), 10:13))
+  arr <- sapply(1:3, function (i) trees[[i]])
+
+  expect_error(as.Splits(arr[-2, ]))
+  expect_equal(as.Splits(trees), as.Splits(arr))
+
+  trees <- list(BalancedTree(1:8), PectinateTree(1:8),
+                CollapseNode(BalancedTree(1:8), 10:13))
+  expect_equivalent(as.Splits(trees), as.Splits(arr[-3, ]))
+
+  exp <- as.Splits(BalancedTree(8))
+  attr(exp, 'tip.label') <- NULL
+  expect_equal("Tips not labelled.", capture.output(summary(exp))[9])
+  expect_equal(exp, as.Splits(BalancedTree(8)$edge))
+})
+
+test_that('as.Splits.edge()', {
+  expect_equivalent(matrix(as.raw(0x03)),
+                    as.Splits(BalancedTree(4), asSplits = FALSE))
+})
+
+test_that('as.Splits.logical()', {
+  FFTT <- c(FALSE, FALSE, TRUE, TRUE)
+  a..d <- letters[1:4]
+  expect_equivalent(as.Splits(BalancedTree(a..d)), as.Splits(!FFTT, a..d))
+  expect_equivalent(as.Splits(FFTT, a..d), as.Splits(t(matrix(FFTT)), a..d))
+  expect_equivalent(as.Splits(FFTT), as.Splits(t(matrix(FFTT))))
+})
+
+test_that('empty as.X.Splits()', {
+  someSplit <- as.Splits(BalancedTree(6))
+  noSplit <- someSplit[[logical(0)]]
+  expect_equal(matrix(logical(0), 0, 6,
+                      dimnames = list(NULL, paste0('t', 1:6))),
+               as.logical(noSplit))
+  expect_equal(character(0), as.character(noSplit))
 })
 
 
@@ -99,14 +198,22 @@ test_that('Renaming splits', {
 
 })
 
-test_that('match.Splits', {
+test_that('match.Splits()', {
   tree1 <- PectinateTree(1:8)
   tree2 <- PectinateTree(8:1)
   col2 <- as.Splits(CollapseNode(tree2, 13))
 
-  expect_equal(5:1, match.Splits(as.Splits(tree1), as.Splits(tree2, tree1)))
-  expect_equal(c(4, 3, NA, 2, 1), match.Splits(as.Splits(tree1, tree2), col2))
-  expect_equal(c(5, 4, 2, 1), match.Splits(col2, as.Splits(tree1, tree2)))
+  expect_equal(5:1, match(as.Splits(tree1), as.Splits(tree2, tree1)))
+  expect_equal(c(4, 3, NA, 2, 1), match(as.Splits(tree1, tree2), col2))
+  expect_equal(c(4, 3, 999, 2, 1),
+               match(as.Splits(tree1, tree2), col2, nomatch = 999))
+  expect_equal(c(5, 4, 2, 1), match(col2, as.Splits(tree1, tree2)))
+})
+
+test_that("print.Splits()", {
+  expect_equal(c( "1 bipartition split dividing 4 tips, t1 .. t4",
+                  "    1234", " 6  **.."),
+               capture.output(print(as.Splits(BalancedTree(4)), details = TRUE)))
 })
 
 test_that("Split operations", {
@@ -133,6 +240,9 @@ test_that("Split operations", {
 
   namedSplits <- as.Splits(BalancedTree(8))
   expect_equal(c('12', '14'), rownames(namedSplits[[c(3, 4)]]))
+
+  expect_equal(split1[], `[[.Splits`(split1))
+  expect_error(c(split1, notSplit1)[[2:1, 1]])
 })
 
 test_that("Split subtraction", {
@@ -158,7 +268,7 @@ test_that("Split combination", {
                     c(splits1, as.Splits(RenumberTips(tree3, letters[1:5])))[, 1])
   expect_equal(2L, length(unique(c(splits1, as.Splits(tree2)))))
 
-  expect_equal(c('7' = 2, '9' = 2), TipsInSplits(splits1))
+  expect_equal(c('8' = 2, '9' = 2), TipsInSplits(splits1))
 
   #TODO: Fully test splits with large (> 8 tip) trees
 })
